Package: HSAUR2
Title: A Handbook of Statistical Analyses Using R (2nd Edition)
Date: 2025-05-02
Version: 1.1-21
Authors@R: c(person("Torsten", "Hothorn", role = c("aut", "cre"),
                 email = "Torsten.Hothorn@R-project.org", comment = c(ORCID = "0000-0001-8301-0471")),
          person(given = c("Brian", "S."),
                 family = "Everitt",
                 role = "aut"))
Description: Functions, data sets, analyses and examples from the 
  second edition of the book 
  ''A Handbook of Statistical Analyses Using R'' (Brian S. Everitt and Torsten
  Hothorn, Chapman & Hall/CRC, 2008). The first chapter
  of the book, which is entitled ''An Introduction to R'', 
  is completely included in this package, for all other chapters,
  a vignette containing all data analyses is available. In addition,
  the package contains Sweave code for producing slides for selected
  chapters (see HSAUR2/inst/slides).
Depends: R (>= 2.2.0), tools
Suggests: lattice, MASS, scatterplot3d (>= 0.3-23), ape (>= 1.6), coin
        (>= 1.1-3), flexmix (>= 1.1-0), gee (>= 4.13-10), lme4 (>=
        0.98-1), mclust (>= 3.0-0), party (>= 0.2-8), randomForest (>=
        4.5-12), rmeta (>= 2.12), vcd (>= 0.9-3), survival, rpart,
        gamair, multcomp (>= 1.0-3), sandwich, mboost, KernSmooth,
        Matrix, boot, mgcv, mvtnorm, partykit, wordcloud, TH.data
LazyData: yes
License: GPL-2
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2025-05-02 09:40:54 UTC; hothorn
Author: Torsten Hothorn [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-8301-0471>),
  Brian S. Everitt [aut]
Maintainer: Torsten Hothorn <Torsten.Hothorn@R-project.org>
Repository: CRAN
Date/Publication: 2025-05-02 14:30:21 UTC
Built: R 4.3.3; ; 2025-05-02 17:25:28 UTC; unix
