
export(HSAURtable)

import(utils)
importFrom("tools", "delimMatch")
importFrom("stats", "complete.cases")

S3method(HSAURtable, table)
S3method(HSAURtable, data.frame)
S3method(toLatex, tabtab)
S3method(toLatex, dftab)
# S3method(toBibtex, HSAURcitation)